@@ -18,7 +18,7 @@ class ShareData (BoundData):
     def template(self):
         return Node(
             'share',
-            *[PropertyNode(x.replace(' ', '_'), y) for x, y in zip(ShareData.fields, ShareData.defaults)]
+            *[PropertyNode(x, y) for x, y in zip(ShareData.fields, ShareData.defaults)]
         )
 
 
@@ -28,10 +28,12 @@ NetatalkData.bind_collection('shares', selector=lambda x: x.name != 'Global', it
 
 GlobalData.bind_property('afp port', 'afp_port', default='548')
 GlobalData.bind_property('cnid listen', 'cnid_listen', default='localhost:4700')
+GlobalData.bind_property('uam list', 'uam_list', default='uams_dhx.so,uams_dhx2.so')
 GlobalData.bind_property(
     'zeroconf', 'zeroconf', default=True,
     getter=yn_getter, setter=yn_setter)
 
 ShareData.bind_name('name')
+ShareData.bind_attribute('comment', 'comment', path=lambda x: x.get('path'), default='')
 for f, d in zip(ShareData.fields, ShareData.defaults):
     ShareData.bind_property(f, f.replace(' ', '_'), default=d)
